# Copyright (c) 2014, 2015  Dave Love, University of Liverpool
# Licence as for the package itself

# fixme: various incorrect-fsf-address warnings from rpmlint
# fixme:  The bundled libraries have relevant-looking patches for
#         dyninst/symtab-8.1.2 (but not 8.2) and one for libunwind on ppc
#         that doesn't look general (maybe just exclude ppc)
#         Filter requires/provides

%bcond_with mpich
%bcond_with mvapich

%if !0%{?papidir}
%if 0%{?el6}
# Account for the horrible mess of %%_libdir/libpapi.so having a
# soname of libpapi.so.  See also the build section.
%global papidir %_libdir/papi-5.1.1/usr
%else
%global papidir %_prefix
%endif
%endif

%global mainvers 2.2
%global patchlevel %nil

Name:           openspeedshop
Version:        %mainvers%patchlevel
Release:        3%{?dist}
Summary:        HPC performance analysis
License:        GPLv2+
URL:            http://www.openspeedshop.org/
Source0:        openspeedshop-%mainvers.tar.gz
# use DESTDIR for installation
Patch1:         openspeedshop-inst.patch
# fix roff error
Patch2:         openspeedshop-man.patch
# recognize OPENSS_MPI_IMPLEMENTATION==OPENMPI, as set by configure
Patch3:		openspeedshop-ompi.patch
# set extra variables
Patch4:		openspeedshop-driver.patch
# fix autotools files
Patch5:		openspeedshop-bootstrap.patch

BuildRequires:  dyninst-devel openmpi-devel qt3-devel sqlite-devel
%if %{with mpich}
BuildRequires:	mpich-devel
%endif
%if %{with mvapich}
BuildRequires:	mvapich2-devel
%endif
BuildRequires:  python-devel binutils-devel libunwind-devel
BuildRequires:  boost-devel zlib-devel chrpath libmonitor-devel
BuildRequires:  automake libtool-ltdl-devel libtool bison flex
BuildRequires:	papi-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
# Avoid rpmlint warning you'd get from requiring libmonitor-devel to get
# this (used by osslink).  Other .a metioned in osslink aren't used.
Requires:	%_libdir/libmonitor.so

%description
Open|SpeedShop is a community effort by The Krell Institute with
current direct funding from DOE’s NNSA and Office of Science.  It is
building on top of a broad list of community infrastructures, most
notably Dyninst and MRNet from UW, libmonitor from Rice, and PAPI from
UTK.  Open|SpeedShop is an open source multi platform Linux
performance tool which is targeted to support performance analysis of
applications running on both single node and large scale IA64, IA32,
EM64T, AMD64, PPC, Blue Gene and Cray platforms.

Open|SpeedShop is explicitly designed with usability in mind and is
for application developers and computer scientists.  The base
functionality include:

    Sampling Experiments
    Support for Callstack Analysis
    Hardware Performance Counters
    MPI Profiling and Tracing
    I/O Profiling and Tracing
    Floating Point Exception Analysis

In addition, Open|SpeedShop is designed to be modular and extensible.
It supports several levels of plug-ins which allow users to add their
own performance experiments.

%package openmpi
Summary:        OpenMPI component of %name
Requires:	%{name}%{?_isa} = %{version}-%{release}
Requires:	openmpi%{?_isa}

%description openmpi
Open|SpeedShop MPI experiment components for openmpi.

%if %{with mpich}
%package mpich
Summary:        Mpich component of %name
Requires:	%{name}%{?_isa} = %{version}-%{release}
Requires:	mpich%{?_isa}

%description mpich
Open|SpeedShop MPI experiment components for mpich.
%endif

%if %{with mvapich}
%package mvapich
Summary:        Mvapich component of %name
Requires:	%{name}%{?_isa} = %{version}-%{release}
Requires:	mvapich2%{?_isa}

%description mvapich
Open|SpeedShop MPI experiment components for mvapich.
%endif

%package gui
Summary:	The Open|SpeedShop GUI
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description gui
The graphical user interface component of Open|SpeedShop.

%package doc
Summary:        Documentation for %name
BuildArch:      noarch

%description doc
Documentation for %name.

%prep
%setup -q -n %name-%mainvers
find -name CVS | xargs rm -rf
#tar fx SOURCES/openspeedshop-2.1.tar.gz
%patch1 -p1 -b .inst
%patch2 -p2 -b .man
%patch3 -p1 -b .ompi
%patch4 -p2 -b .driver
%patch5 -p1 -b .boot
#pushd openspeedshop-2.1
./bootstrap
#popd
# packaging guidelines say delete bundled stuff
#rm -r SOURCES
# There's a lot flagged by rpmlint on debuginfo
find -name \*.xpm -o -name \*.[ch]xx -exec chmod 0644 {} \;

%build
#pushd openspeedshop-2.1

# The rpmbuild flags break it so that you don't get any profiling out.
# It's not clear why.
export CFLAGS='-g -O2'
export LDFLAGS="-Wl,--as-needed"
# The otf support depends on vampirtrace; in principle that's availale
# from openmpi, but not all the necessary headers are installed by it.
%configure --with-openmpi=%_libdir/openmpi \
%if %{with mpich}
	   --with-mpich2=%_libdir/mpich \
%endif
%if %{with mvapich}
	   --with-mvapich2=%_libdir/mvapich2 \
%endif
           --with-papi=%papidir \
           --with-dyninst-libdir=%_libdir/dyninst --disable-rpath
# Setting the PAPI directory isn't enough to prevent libpapi.so getting
# linked and subsequently picking up the wrong thing.
 find \( -name Makefile -o -name createPluginStructure.py \) -exec sed -r -i 's,-L%_libdir/?( |$),,g;s,-L/usr/lib/../%_lib ,,g' {} \;
# Not smp-safe.  (Maybe some bits are.)
make


%install
make install DESTDIR=$RPM_BUILD_ROOT
find $RPM_BUILD_ROOT%_libdir -name \*.la -exec rm {} \;
mv $RPM_BUILD_ROOT%_datadir/doc/packages/OpenSpeedShop built-doc
rmdir $RPM_BUILD_ROOT%_datadir/doc/packages
chmod 0644 $RPM_BUILD_ROOT%_libdir/*/*.py
# PYopenss.so is a dangling link until installed
find $RPM_BUILD_ROOT%_libdir -name \*.so | grep -v PYopenss.so | xargs chrpath -d
install -m755 openss/openss $RPM_BUILD_ROOT%_bindir


%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%post gui -p /sbin/ldconfig
%postun gui -p /sbin/ldconfig

%files
%doc COPYING
%_bindir/oss*
%_bindir/openss
%exclude %_libdir/%name/*Wizard*
%exclude %_libdir/%name/*Panel*
# we don't have the plugin (see build section)
%exclude %_bindir/ossmpiotf
%_libdir/libopenss-cli*.so*
%_libdir/libopenss-framework*.so*
%_libdir/libopenss-message*.so*
%_libdir/libopenss-queries*.so*
%_libdir/*.a
%_libdir/%name
%_mandir/man1/*
%_mandir/man3/*
%_includedir/*

%files openmpi
%_libdir/%name/*openmpi*

%if %{with mpich}
%files mpich
%_libdir/%name/*mpich*
%endif

%if %{with mvapich}
%files mvapich
%_libdir/%name/*mvapich*
%endif


%files gui
%_libdir/libopenss-gui*.so*
%_libdir/libopenss-CustomExperimentPanel.so*
%_libdir/libopenss-ExprInfo.so*
%_libdir/%name/*Wizard*
%_libdir/%name/*Panel*

%files doc
%doc built-doc/*

%changelog
* Sun Jan 24 2016 Dave Love <loveshack@fedoraproject.org> - 2.2-3
- Build against papi54 on el6

* Thu Jan  7 2016 Dave Love <loveshack@fedoraproject.org> - 2.2-2
- Updated tarball with same version

* Sat Nov 28 2015 Dave Love <loveshack@fedoraproject.org> - 2.2-1
- Add openspeedshop-bootstrap.patch
- Remove CVS dirs

* Fri Nov 27 2015 Dave Love <loveshack@fedoraproject.org> - 2.2-1
- New version

* Sat Aug 15 2015 Dave Love <d.love@liverpool.ac.uk> - 2.1.8-2
- Source tarball changed

* Mon Jul 20 2015 Dave Love <d.love@liverpool.ac.uk> - 2.1.8-1
- New version

* Tue Apr  7 2015 Dave Love <d.love@liverpool.ac.uk> - 2.1.7a-3
- Use simple tarball, not the _release one with all the junk

* Sun Apr  5 2015 Dave Love <d.love@liverpool.ac.uk> - 2.1.7a-2
- BR libunwind-devel

* Sun Apr  5 2015 Dave Love <d.love@liverpool.ac.uk> - 2.1.7a-2
- Don't use rpmbuild-supplied CFLAGS -- breaks profiling
- Set DYNINSTAPI_RT_LIB and OPENSS_MPI_IMPLEMENTATION in driver
- MPI-specific packages
- Dont remove .a
- Don't BR libdwarf
- Conditionalize mvapich
- Remove vt patch

* Sat Feb 21 2015 Dave Love <d.love@liverpool.ac.uk> - 2.1.7a-1
- New version

* Thu Nov 20 2014 Dave Love <d.love@liverpool.ac.uk> - 2.1.5-2
- Remove openss from gui package

* Wed Nov 12 2014 Dave Love <d.love@liverpool.ac.uk> - 2.1.5-1
- New version

* Tue Oct 14 2014 Dave Love <d.love@liverpool.ac.uk> - 2.1.3-2
- Drop devel package, since openss needs .so anyway
- Fix openss install
- Effectively require libdwarf-tools libmonitor
- Add man page patch

* Sun Aug 31 2014 Dave Love <d.love@liverpool.ac.uk> - 2.1.3-1
- New version
- BR libmonitor-devel

* Thu Jul 24 2014 Dave Love <d.love@liverpool.ac.uk> - 2.1.3-1
- Initial packaging
